@@ -8,7 +8,7 @@ use CGI::Wiki::Store::Database;
 use Carp qw/carp croak/;
 
 @ISA = qw( CGI::Wiki::Store::Database );
-$VERSION = 0.04;
+$VERSION = 0.01;
 
 =head1 NAME
 
@@ -32,9 +32,11 @@ sub _dsn {
 
 =item B<new>
 
-  my $store = CGI::Wiki::Store::SQLite->new( dbname => "wiki" );
+  my $store = CGI::Wiki::Store::SQLite->new( dbname => "wiki",
+                                    checksum_method => \&md5_hex );
 
-The dbname parameter is mandatory.
+The dbname parameter is mandatory. If you want defaults done for you
+then get at it via CGI::Wiki instead.
 
 =cut
 
@@ -51,19 +53,18 @@ sub new {
 =item B<check_and_write_node>
 
   $store->check_and_write_node( node     => $node,
-				checksum => $checksum,
-                                %other_args );
+				content  => $content,
+				checksum => $checksum ) or return 0;
 
-Locks the node, verifies the checksum, calls
-C<write_node_post_locking> with all supplied arguments, unlocks the
-node. Returns 1 on successful writing, 0 if checksum doesn't match,
-croaks on error.
+Locks the node, verifies the checksum and writes the content to the
+node, unlocks the node.  Returns 1 on success, 0 if checksum doesn't
+match, croaks on error.
 
 =cut
 
 sub check_and_write_node {
     my ($self, %args) = @_;
-    my ($node, $checksum) = @args{qw( node checksum )};
+    my ($node, $content, $checksum) = @args{qw(node content checksum)};
 
     my $dbh = $self->{_dbh};
     $dbh->{AutoCommit} = 0;
@@ -72,17 +73,16 @@ sub check_and_write_node {
         $dbh->do("END TRANSACTION");
         $dbh->do("BEGIN TRANSACTION");
         $self->verify_checksum($node, $checksum) or return 0;
-        $self->write_node_post_locking( %args );
+        $self->write_node_after_locking($node, $content);
     };
     if ($@) {
         my $error = $@;
         $dbh->rollback;
 	$dbh->{AutoCommit} = 1;
-	if (   $error =~ /database is locked/
-            or $error =~ /DBI connect.+failed/ ) {
+	if ($error =~ /database is locked/) {
             return 0;
         } else {
-            croak "Unhandled error: [$error]";
+            croak $error;
         }
     } else {
         $dbh->commit;
@@ -91,21 +91,5 @@ sub check_and_write_node {
     }
 }
 
-sub _get_list_by_metadata_sql {
-    my ($self, %args) = @_;
-    if ( $args{ignore_case} ) {
-        return "SELECT node.name FROM node, metadata"
-             . " WHERE node.name=metadata.node"
-             . " AND node.version=metadata.version"
-             . " AND metadata.metadata_type LIKE ? "
-             . " AND metadata.metadata_value LIKE ? ";
-    } else {
-        return "SELECT node.name FROM node, metadata"
-             . " WHERE node.name=metadata.node"
-             . " AND node.version=metadata.version"
-             . " AND metadata.metadata_type = ? "
-             . " AND metadata.metadata_value = ? ";
-    }
-}
 
 1;
